@@ -93,7 +93,7 @@ def set_api_key(key):
     if system_platform == "windows":
         set_env_variable_command = f'setx OPENAI_API_KEY "{key}"'
         subprocess.call(set_env_variable_command, shell=True)
-        click.echo("OPENAI_API_KEY has been set.")
+        click.echo("✅ Success, OPENAI_API_KEY has been set.\nPlease restart your Command Prompt to apply the changes.")
     elif system_platform in ["linux", "darwin"]:
         if "OPENAI_API_KEY" in os.environ or is_key_set_in_config_file(key):
             if not click.confirm("OPENAI_API_KEY is already set. Do you want to overwrite it?"):
